piecenorms has been built to calculate normalised data piecewise
using class intervals. This is useful in communication of highly skewed data.
Maintainer: David Hammond anotherdavidhammond@gmail.com
For highly skewed data, the package classInt provides a series of options
for selecting class intervals. The classInts can be used as the breaks for
calculating the piecewise normalisation function piecenorm. The function
also allows the user to select their own breaks manually.
For any call to piecenorm, the user provides a vector of observations,
a vector of breaks and a direction for the normalisation. The data is then
cut into classes and normalised within its class.
Number of Bins: $$ n = \text{length}(\text{brks}) - 1$$ Normalisation Class Intervals: $$\left(\frac{i-1}{n}, \frac{i}{n}\right] \forall i \in \{1:n\}$$
In cases where there is only one bin defined as c(min(obs), max(obs)),
the function piecenorm resolves to standard minmax normalisation.
The piecenorms package also provides a normalisr R6 class that
Classifies data into a likely distribution family
Provides a recommendation of an appropriate normalisation technique
Provides functionality to apply this normalisation technique to a new data set
This is useful when the user would like to analyse how distributions have changed over time.
Useful links: